/****************************************************************************
** Meta object code from reading C++ file 'test-qt.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "test-qt.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'test-qt.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_ProgressCounter_t {
    QByteArrayData data[3];
    char stringdata0[26];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ProgressCounter_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ProgressCounter_t qt_meta_stringdata_ProgressCounter = {
    {
QT_MOC_LITERAL(0, 0, 15), // "ProgressCounter"
QT_MOC_LITERAL(1, 16, 8), // "progress"
QT_MOC_LITERAL(2, 25, 0) // ""

    },
    "ProgressCounter\0progress\0"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ProgressCounter[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   19,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void,

       0        // eod
};

void ProgressCounter::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        ProgressCounter *_t = static_cast<ProgressCounter *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->progress(); break;
        default: ;
        }
    }
    Q_UNUSED(_a);
}

const QMetaObject ProgressCounter::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_ProgressCounter.data,
      qt_meta_data_ProgressCounter,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *ProgressCounter::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ProgressCounter::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ProgressCounter.stringdata0))
        return static_cast<void*>(const_cast< ProgressCounter*>(this));
    return QObject::qt_metacast(_clname);
}

int ProgressCounter::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}
struct qt_meta_stringdata_InstallProgressCounter_t {
    QByteArrayData data[3];
    char stringdata0[33];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_InstallProgressCounter_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_InstallProgressCounter_t qt_meta_stringdata_InstallProgressCounter = {
    {
QT_MOC_LITERAL(0, 0, 22), // "InstallProgressCounter"
QT_MOC_LITERAL(1, 23, 8), // "progress"
QT_MOC_LITERAL(2, 32, 0) // ""

    },
    "InstallProgressCounter\0progress\0"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_InstallProgressCounter[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   19,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void,

       0        // eod
};

void InstallProgressCounter::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        InstallProgressCounter *_t = static_cast<InstallProgressCounter *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->progress(); break;
        default: ;
        }
    }
    Q_UNUSED(_a);
}

const QMetaObject InstallProgressCounter::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_InstallProgressCounter.data,
      qt_meta_data_InstallProgressCounter,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *InstallProgressCounter::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *InstallProgressCounter::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_InstallProgressCounter.stringdata0))
        return static_cast<void*>(const_cast< InstallProgressCounter*>(this));
    return QObject::qt_metacast(_clname);
}

int InstallProgressCounter::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}
struct qt_meta_stringdata_GetSystemInformationHandler_t {
    QByteArrayData data[3];
    char stringdata0[40];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_GetSystemInformationHandler_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_GetSystemInformationHandler_t qt_meta_stringdata_GetSystemInformationHandler = {
    {
QT_MOC_LITERAL(0, 0, 27), // "GetSystemInformationHandler"
QT_MOC_LITERAL(1, 28, 10), // "onComplete"
QT_MOC_LITERAL(2, 39, 0) // ""

    },
    "GetSystemInformationHandler\0onComplete\0"
    ""
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_GetSystemInformationHandler[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   19,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void,

       0        // eod
};

void GetSystemInformationHandler::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        GetSystemInformationHandler *_t = static_cast<GetSystemInformationHandler *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->onComplete(); break;
        default: ;
        }
    }
    Q_UNUSED(_a);
}

const QMetaObject GetSystemInformationHandler::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_GetSystemInformationHandler.data,
      qt_meta_data_GetSystemInformationHandler,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *GetSystemInformationHandler::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *GetSystemInformationHandler::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_GetSystemInformationHandler.stringdata0))
        return static_cast<void*>(const_cast< GetSystemInformationHandler*>(this));
    return QObject::qt_metacast(_clname);
}

int GetSystemInformationHandler::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}
struct qt_meta_stringdata_ListHandler_t {
    QByteArrayData data[3];
    char stringdata0[24];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ListHandler_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ListHandler_t qt_meta_stringdata_ListHandler = {
    {
QT_MOC_LITERAL(0, 0, 11), // "ListHandler"
QT_MOC_LITERAL(1, 12, 10), // "onComplete"
QT_MOC_LITERAL(2, 23, 0) // ""

    },
    "ListHandler\0onComplete\0"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ListHandler[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   19,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void,

       0        // eod
};

void ListHandler::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        ListHandler *_t = static_cast<ListHandler *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->onComplete(); break;
        default: ;
        }
    }
    Q_UNUSED(_a);
}

const QMetaObject ListHandler::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_ListHandler.data,
      qt_meta_data_ListHandler,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *ListHandler::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ListHandler::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ListHandler.stringdata0))
        return static_cast<void*>(const_cast< ListHandler*>(this));
    return QObject::qt_metacast(_clname);
}

int ListHandler::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}
struct qt_meta_stringdata_ListOneHandler_t {
    QByteArrayData data[3];
    char stringdata0[27];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ListOneHandler_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ListOneHandler_t qt_meta_stringdata_ListOneHandler = {
    {
QT_MOC_LITERAL(0, 0, 14), // "ListOneHandler"
QT_MOC_LITERAL(1, 15, 10), // "onComplete"
QT_MOC_LITERAL(2, 26, 0) // ""

    },
    "ListOneHandler\0onComplete\0"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ListOneHandler[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   19,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void,

       0        // eod
};

void ListOneHandler::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        ListOneHandler *_t = static_cast<ListOneHandler *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->onComplete(); break;
        default: ;
        }
    }
    Q_UNUSED(_a);
}

const QMetaObject ListOneHandler::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_ListOneHandler.data,
      qt_meta_data_ListOneHandler,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *ListOneHandler::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ListOneHandler::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ListOneHandler.stringdata0))
        return static_cast<void*>(const_cast< ListOneHandler*>(this));
    return QObject::qt_metacast(_clname);
}

int ListOneHandler::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}
struct qt_meta_stringdata_GetIconHandler_t {
    QByteArrayData data[3];
    char stringdata0[27];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_GetIconHandler_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_GetIconHandler_t qt_meta_stringdata_GetIconHandler = {
    {
QT_MOC_LITERAL(0, 0, 14), // "GetIconHandler"
QT_MOC_LITERAL(1, 15, 10), // "onComplete"
QT_MOC_LITERAL(2, 26, 0) // ""

    },
    "GetIconHandler\0onComplete\0"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_GetIconHandler[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   19,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void,

       0        // eod
};

void GetIconHandler::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        GetIconHandler *_t = static_cast<GetIconHandler *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->onComplete(); break;
        default: ;
        }
    }
    Q_UNUSED(_a);
}

const QMetaObject GetIconHandler::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_GetIconHandler.data,
      qt_meta_data_GetIconHandler,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *GetIconHandler::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *GetIconHandler::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_GetIconHandler.stringdata0))
        return static_cast<void*>(const_cast< GetIconHandler*>(this));
    return QObject::qt_metacast(_clname);
}

int GetIconHandler::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}
struct qt_meta_stringdata_FindHandler_t {
    QByteArrayData data[3];
    char stringdata0[24];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_FindHandler_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_FindHandler_t qt_meta_stringdata_FindHandler = {
    {
QT_MOC_LITERAL(0, 0, 11), // "FindHandler"
QT_MOC_LITERAL(1, 12, 10), // "onComplete"
QT_MOC_LITERAL(2, 23, 0) // ""

    },
    "FindHandler\0onComplete\0"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_FindHandler[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   19,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void,

       0        // eod
};

void FindHandler::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        FindHandler *_t = static_cast<FindHandler *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->onComplete(); break;
        default: ;
        }
    }
    Q_UNUSED(_a);
}

const QMetaObject FindHandler::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_FindHandler.data,
      qt_meta_data_FindHandler,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *FindHandler::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *FindHandler::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_FindHandler.stringdata0))
        return static_cast<void*>(const_cast< FindHandler*>(this));
    return QObject::qt_metacast(_clname);
}

int FindHandler::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}
struct qt_meta_stringdata_InstallHandler_t {
    QByteArrayData data[3];
    char stringdata0[27];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_InstallHandler_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_InstallHandler_t qt_meta_stringdata_InstallHandler = {
    {
QT_MOC_LITERAL(0, 0, 14), // "InstallHandler"
QT_MOC_LITERAL(1, 15, 10), // "onComplete"
QT_MOC_LITERAL(2, 26, 0) // ""

    },
    "InstallHandler\0onComplete\0"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_InstallHandler[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   19,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void,

       0        // eod
};

void InstallHandler::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        InstallHandler *_t = static_cast<InstallHandler *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->onComplete(); break;
        default: ;
        }
    }
    Q_UNUSED(_a);
}

const QMetaObject InstallHandler::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_InstallHandler.data,
      qt_meta_data_InstallHandler,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *InstallHandler::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *InstallHandler::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_InstallHandler.stringdata0))
        return static_cast<void*>(const_cast< InstallHandler*>(this));
    return QObject::qt_metacast(_clname);
}

int InstallHandler::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}
struct qt_meta_stringdata_InstallErrorHandler_t {
    QByteArrayData data[3];
    char stringdata0[32];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_InstallErrorHandler_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_InstallErrorHandler_t qt_meta_stringdata_InstallErrorHandler = {
    {
QT_MOC_LITERAL(0, 0, 19), // "InstallErrorHandler"
QT_MOC_LITERAL(1, 20, 10), // "onComplete"
QT_MOC_LITERAL(2, 31, 0) // ""

    },
    "InstallErrorHandler\0onComplete\0"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_InstallErrorHandler[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   19,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void,

       0        // eod
};

void InstallErrorHandler::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        InstallErrorHandler *_t = static_cast<InstallErrorHandler *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->onComplete(); break;
        default: ;
        }
    }
    Q_UNUSED(_a);
}

const QMetaObject InstallErrorHandler::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_InstallErrorHandler.data,
      qt_meta_data_InstallErrorHandler,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *InstallErrorHandler::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *InstallErrorHandler::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_InstallErrorHandler.stringdata0))
        return static_cast<void*>(const_cast< InstallErrorHandler*>(this));
    return QObject::qt_metacast(_clname);
}

int InstallErrorHandler::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}
struct qt_meta_stringdata_InstallCancelHandler_t {
    QByteArrayData data[3];
    char stringdata0[33];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_InstallCancelHandler_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_InstallCancelHandler_t qt_meta_stringdata_InstallCancelHandler = {
    {
QT_MOC_LITERAL(0, 0, 20), // "InstallCancelHandler"
QT_MOC_LITERAL(1, 21, 10), // "onComplete"
QT_MOC_LITERAL(2, 32, 0) // ""

    },
    "InstallCancelHandler\0onComplete\0"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_InstallCancelHandler[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   19,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void,

       0        // eod
};

void InstallCancelHandler::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        InstallCancelHandler *_t = static_cast<InstallCancelHandler *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->onComplete(); break;
        default: ;
        }
    }
    Q_UNUSED(_a);
}

const QMetaObject InstallCancelHandler::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_InstallCancelHandler.data,
      qt_meta_data_InstallCancelHandler,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *InstallCancelHandler::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *InstallCancelHandler::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_InstallCancelHandler.stringdata0))
        return static_cast<void*>(const_cast< InstallCancelHandler*>(this));
    return QObject::qt_metacast(_clname);
}

int InstallCancelHandler::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}
struct qt_meta_stringdata_InstallMultipleHandler_t {
    QByteArrayData data[3];
    char stringdata0[35];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_InstallMultipleHandler_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_InstallMultipleHandler_t qt_meta_stringdata_InstallMultipleHandler = {
    {
QT_MOC_LITERAL(0, 0, 22), // "InstallMultipleHandler"
QT_MOC_LITERAL(1, 23, 10), // "onComplete"
QT_MOC_LITERAL(2, 34, 0) // ""

    },
    "InstallMultipleHandler\0onComplete\0"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_InstallMultipleHandler[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   19,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void,

       0        // eod
};

void InstallMultipleHandler::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        InstallMultipleHandler *_t = static_cast<InstallMultipleHandler *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->onComplete(); break;
        default: ;
        }
    }
    Q_UNUSED(_a);
}

const QMetaObject InstallMultipleHandler::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_InstallMultipleHandler.data,
      qt_meta_data_InstallMultipleHandler,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *InstallMultipleHandler::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *InstallMultipleHandler::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_InstallMultipleHandler.stringdata0))
        return static_cast<void*>(const_cast< InstallMultipleHandler*>(this));
    return QObject::qt_metacast(_clname);
}

int InstallMultipleHandler::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}
struct qt_meta_stringdata_InstallMultipleCancelFirstHandler_t {
    QByteArrayData data[5];
    char stringdata0[83];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_InstallMultipleCancelFirstHandler_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_InstallMultipleCancelFirstHandler_t qt_meta_stringdata_InstallMultipleCancelFirstHandler = {
    {
QT_MOC_LITERAL(0, 0, 33), // "InstallMultipleCancelFirstHan..."
QT_MOC_LITERAL(1, 34, 15), // "onCompleteSnap1"
QT_MOC_LITERAL(2, 50, 0), // ""
QT_MOC_LITERAL(3, 51, 15), // "onCompleteSnap2"
QT_MOC_LITERAL(4, 67, 15) // "onCompleteSnap3"

    },
    "InstallMultipleCancelFirstHandler\0"
    "onCompleteSnap1\0\0onCompleteSnap2\0"
    "onCompleteSnap3"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_InstallMultipleCancelFirstHandler[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       3,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   29,    2, 0x0a /* Public */,
       3,    0,   30,    2, 0x0a /* Public */,
       4,    0,   31,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void InstallMultipleCancelFirstHandler::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        InstallMultipleCancelFirstHandler *_t = static_cast<InstallMultipleCancelFirstHandler *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->onCompleteSnap1(); break;
        case 1: _t->onCompleteSnap2(); break;
        case 2: _t->onCompleteSnap3(); break;
        default: ;
        }
    }
    Q_UNUSED(_a);
}

const QMetaObject InstallMultipleCancelFirstHandler::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_InstallMultipleCancelFirstHandler.data,
      qt_meta_data_InstallMultipleCancelFirstHandler,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *InstallMultipleCancelFirstHandler::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *InstallMultipleCancelFirstHandler::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_InstallMultipleCancelFirstHandler.stringdata0))
        return static_cast<void*>(const_cast< InstallMultipleCancelFirstHandler*>(this));
    return QObject::qt_metacast(_clname);
}

int InstallMultipleCancelFirstHandler::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 3;
    }
    return _id;
}
struct qt_meta_stringdata_InstallMultipleCancelLastHandler_t {
    QByteArrayData data[5];
    char stringdata0[82];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_InstallMultipleCancelLastHandler_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_InstallMultipleCancelLastHandler_t qt_meta_stringdata_InstallMultipleCancelLastHandler = {
    {
QT_MOC_LITERAL(0, 0, 32), // "InstallMultipleCancelLastHandler"
QT_MOC_LITERAL(1, 33, 15), // "onCompleteSnap1"
QT_MOC_LITERAL(2, 49, 0), // ""
QT_MOC_LITERAL(3, 50, 15), // "onCompleteSnap2"
QT_MOC_LITERAL(4, 66, 15) // "onCompleteSnap3"

    },
    "InstallMultipleCancelLastHandler\0"
    "onCompleteSnap1\0\0onCompleteSnap2\0"
    "onCompleteSnap3"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_InstallMultipleCancelLastHandler[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       3,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   29,    2, 0x0a /* Public */,
       3,    0,   30,    2, 0x0a /* Public */,
       4,    0,   31,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void InstallMultipleCancelLastHandler::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        InstallMultipleCancelLastHandler *_t = static_cast<InstallMultipleCancelLastHandler *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->onCompleteSnap1(); break;
        case 1: _t->onCompleteSnap2(); break;
        case 2: _t->onCompleteSnap3(); break;
        default: ;
        }
    }
    Q_UNUSED(_a);
}

const QMetaObject InstallMultipleCancelLastHandler::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_InstallMultipleCancelLastHandler.data,
      qt_meta_data_InstallMultipleCancelLastHandler,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *InstallMultipleCancelLastHandler::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *InstallMultipleCancelLastHandler::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_InstallMultipleCancelLastHandler.stringdata0))
        return static_cast<void*>(const_cast< InstallMultipleCancelLastHandler*>(this));
    return QObject::qt_metacast(_clname);
}

int InstallMultipleCancelLastHandler::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 3;
    }
    return _id;
}
struct qt_meta_stringdata_RemoveHandler_t {
    QByteArrayData data[3];
    char stringdata0[26];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_RemoveHandler_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_RemoveHandler_t qt_meta_stringdata_RemoveHandler = {
    {
QT_MOC_LITERAL(0, 0, 13), // "RemoveHandler"
QT_MOC_LITERAL(1, 14, 10), // "onComplete"
QT_MOC_LITERAL(2, 25, 0) // ""

    },
    "RemoveHandler\0onComplete\0"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_RemoveHandler[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   19,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void,

       0        // eod
};

void RemoveHandler::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        RemoveHandler *_t = static_cast<RemoveHandler *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->onComplete(); break;
        default: ;
        }
    }
    Q_UNUSED(_a);
}

const QMetaObject RemoveHandler::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_RemoveHandler.data,
      qt_meta_data_RemoveHandler,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *RemoveHandler::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *RemoveHandler::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_RemoveHandler.stringdata0))
        return static_cast<void*>(const_cast< RemoveHandler*>(this));
    return QObject::qt_metacast(_clname);
}

int RemoveHandler::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}
struct qt_meta_stringdata_RemoveErrorHandler_t {
    QByteArrayData data[3];
    char stringdata0[31];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_RemoveErrorHandler_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_RemoveErrorHandler_t qt_meta_stringdata_RemoveErrorHandler = {
    {
QT_MOC_LITERAL(0, 0, 18), // "RemoveErrorHandler"
QT_MOC_LITERAL(1, 19, 10), // "onComplete"
QT_MOC_LITERAL(2, 30, 0) // ""

    },
    "RemoveErrorHandler\0onComplete\0"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_RemoveErrorHandler[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   19,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void,

       0        // eod
};

void RemoveErrorHandler::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        RemoveErrorHandler *_t = static_cast<RemoveErrorHandler *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->onComplete(); break;
        default: ;
        }
    }
    Q_UNUSED(_a);
}

const QMetaObject RemoveErrorHandler::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_RemoveErrorHandler.data,
      qt_meta_data_RemoveErrorHandler,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *RemoveErrorHandler::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *RemoveErrorHandler::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_RemoveErrorHandler.stringdata0))
        return static_cast<void*>(const_cast< RemoveErrorHandler*>(this));
    return QObject::qt_metacast(_clname);
}

int RemoveErrorHandler::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}
struct qt_meta_stringdata_RemoveCancelHandler_t {
    QByteArrayData data[3];
    char stringdata0[32];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_RemoveCancelHandler_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_RemoveCancelHandler_t qt_meta_stringdata_RemoveCancelHandler = {
    {
QT_MOC_LITERAL(0, 0, 19), // "RemoveCancelHandler"
QT_MOC_LITERAL(1, 20, 10), // "onComplete"
QT_MOC_LITERAL(2, 31, 0) // ""

    },
    "RemoveCancelHandler\0onComplete\0"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_RemoveCancelHandler[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   19,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void,

       0        // eod
};

void RemoveCancelHandler::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        RemoveCancelHandler *_t = static_cast<RemoveCancelHandler *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->onComplete(); break;
        default: ;
        }
    }
    Q_UNUSED(_a);
}

const QMetaObject RemoveCancelHandler::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_RemoveCancelHandler.data,
      qt_meta_data_RemoveCancelHandler,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *RemoveCancelHandler::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *RemoveCancelHandler::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_RemoveCancelHandler.stringdata0))
        return static_cast<void*>(const_cast< RemoveCancelHandler*>(this));
    return QObject::qt_metacast(_clname);
}

int RemoveCancelHandler::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
